@@ -3,8 +3,8 @@
 pytest_sugar
 ~~~~~~~~~~~~
 
-py.test is a plugin for py.test that changes the default look
-and feel of py.test (e.g. progressbar, show tests that fail instantly).
+pytest-sugar is a plugin for pytest that changes the default look
+and feel of pytest (e.g. progressbar, show tests that fail instantly).
 
 :copyright: see LICENSE for details
 :license: BSD, see LICENSE for more details.
@@ -28,7 +28,7 @@ import pytest
 from _pytest.terminal import TerminalReporter
 
 
-__version__ = '0.9.3'
+__version__ = '0.9.5'
 
 LEN_RIGHT_MARGIN = 0
 LEN_PROGRESS_PERCENTAGE = 5
@@ -64,8 +64,8 @@ PROGRESS_BAR_BLOCKS = [
 ]
 
 
-def flatten(l):
-    for x in l:
+def flatten(seq):
+    for x in seq:
         if isinstance(x, (list, tuple)):
             for y in flatten(x):
                 yield y
@@ -165,9 +165,9 @@ def pytest_configure(config):
         except ImportError:
             pass
         else:
-            from distutils.version import LooseVersion
-            xdist_version = LooseVersion(xdist.__version__)
-            if xdist_version >= LooseVersion('1.14'):
+            from packaging import version
+            xdist_version = version.Version(xdist.__version__)
+            if xdist_version >= version.Version('1.14'):
                 config.pluginmanager.register(DeferredXdistPlugin())
 
     if IS_SUGAR_ENABLED and not getattr(config, 'slaveinput', None):
@@ -238,6 +238,7 @@ class SugarTerminalReporter(TerminalReporter):
             self.print_failure(report)
 
     def pytest_sessionstart(self, session):
+        self._session = session
         self._sessionstarttime = py.std.time.time()
         verinfo = ".".join(map(str, sys.version_info[:3]))
         self.write_line(
@@ -473,13 +474,12 @@ class SugarTerminalReporter(TerminalReporter):
             if not letter and not word:
                 return
             if self.verbosity > 0:
+                markup = {'red': True}
                 if isinstance(word, tuple):
                     word, markup = word
                 else:
                     if report.passed:
                         markup = {'green': True}
-                    elif report.failed:
-                        markup = {'red': True}
                     elif report.skipped:
                         markup = {'yellow': True}
                 line = self._locationline(str(report.fspath), *report.location)
@@ -530,14 +530,7 @@ class SugarTerminalReporter(TerminalReporter):
                 else:
                     path = os.path.dirname(report.location[0])
                     name = os.path.basename(report.location[0])
-                    # Doctest failure reports have lineno=None at least up to
-                    # pytest==3.0.7, but it is available via longrepr object.
-                    try:
-                        lineno = report.longrepr.reprlocation.lineno
-                    except AttributeError:
-                        lineno = report.location[1]
-                        if lineno is not None:
-                            lineno += 1
+                    lineno = self._get_lineno_from_report(report)
                     crashline = '%s%s%s:%s %s' % (
                         colored(path, THEME['path']),
                         '/' if path else '',
@@ -594,6 +587,24 @@ class SugarTerminalReporter(TerminalReporter):
 
         return crashline
 
+    def _get_lineno_from_report(self, report):
+        # Doctest failures in pytest>3.10 are stored in
+        # reprlocation_lines, a list of (ReprFileLocation, lines)
+        try:
+            location, lines = report.longrepr.reprlocation_lines[0]
+            return location.lineno
+        except AttributeError:
+            pass
+        # Doctest failure reports have lineno=None at least up to
+        # pytest==3.0.7, but it is available via longrepr object.
+        try:
+            return report.longrepr.reprlocation.lineno
+        except AttributeError:
+            lineno = report.location[1]
+            if lineno is not None:
+                lineno += 1
+            return lineno
+
     def summary_failures(self):
         # Prevent failure summary from being shown since we already
         # show the failure instantly after failure has occurred.
